@@ -10,11 +10,16 @@
 
 #include <libaio.h>
 
-#if defined(__i386__)
-#define KERNEL_RW_POINTER	((void *)0xc0010000)
-#else
-#error Configure for arch.
-#endif
+/* /dev/andrea */
+#define __KERNEL__
+#include <asm/page.h>
+#undef __KERNEL__
+/*
+ * The below doesn't make sense in some arch with shared
+ * address space betwene kernel and userspace but it'll
+ * probably work by luck there too.
+ */
+#define KERNEL_RW_POINTER       ((void *)PAGE_OFFSET)
 
 
 char test_name[] = TEST_NAME;
