@@ -17,12 +17,10 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 #include <libaio.h>
-#include <errno.h>
-#include <stdlib.h>
 #include <time.h>
-#include "vsys_def.h"
+#include "syscall.h"
 
-int io_getevents(io_context_t ctx, long nr, struct io_event *events, const struct timespec *timeout)
+int io_getevents(io_context_t ctx, long nr, struct io_event *events, struct timespec *timeout)
 {
-	return vsys_io_getevents(ctx, nr, events, timeout);
+	return sys_io_getevents(ctx, 1, nr, events, timeout);
 }
