@@ -16,16 +16,12 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
-#define NO_SYSCALL_ERRNO
-#include <linux/types.h>
 #include <libaio.h>
-#include <errno.h>
-
-#include "vsys_def.h"
+#include "syscall.h"
 
 struct timespec;
 
-int io_queue_wait(io_context_t ctx, const struct timespec *timeout)
+int io_queue_wait(io_context_t ctx, struct timespec *timeout)
 {
-	return vsys_io_getevents(ctx, 0, NULL, timeout);
+	return sys_io_getevents(ctx, 0, 0, NULL, timeout);
 }
